==> BatchSDK-ios-1.21.0.zip: README.md <==
<img src="https://static.batch.com/documentation/Readmes/logo_batch_full_178@2x.png" srcset="https://static.batch.com/documentation/Readmes/logo_batch_full_178.png 1x" width="178" height="80" alt="Batch Logo" />

# Batch iOS SDK

The Batch iOS SDK allows you to build meaningful communication experience in your iOS app through highly personalized push notifications & In-App messages.

Our [📕 setup documentation](https://doc.batch.com/ios/prerequisites) details the steps to take for an easy and successful integration.

# Prerequisites
The Batch iOS SDK requires Xcode 12 and iOS 10.0 or higher.

# Documentation
- [Setup guide](https://doc.batch.com/ios/prerequisites): start your implementation here!
- [Help center](https://help.batch.com/en/): answers to most questions you may have during the integration
- [API reference](https://doc.batch.com/ios-api-reference/index.html): this documents each of the classes and methods in the Batch iOS SDK

You may also find this guide useful to review after integration to make sure you're ready to go live: [How can I test the integration on iOS?](https://help.batch.com/en/articles/2669866-how-can-i-test-the-integration-on-ios)

# Releases
We support Cocoapods, Carthage and SPM. You can also [integrate the Batch iOS SDK manually](https://doc.batch.com/ios/advanced/general#manual-framework-integration). 
 
# Building

Build instructions are detailed in [BUILDING.md](BUILDING.md).

# Contributing
Please refer to our [contributing guidelines](CONTRIBUTING.md).

==> BatchSDK-ios-2.1.0.zip: README.md <==
<img src="https://static.batch.com/documentation/Readmes/logo_batch_full_178@2x.png" srcset="https://static.batch.com/documentation/Readmes/logo_batch_full_178.png 1x" width="178" height="80" alt="Batch Logo" />

# Batch iOS SDK

The Batch iOS SDK allows you to build meaningful communication experience in your iOS app through highly personalized push notifications & In-App messages.

Our [📕 setup documentation](https://doc.batch.com/ios/prerequisites) details the steps to take for an easy and successful integration.

# Prerequisites
The Batch iOS SDK requires Xcode 15.3 and iOS 13.0 or higher.

# Documentation
- [Setup guide](https://doc.batch.com/ios/prerequisites): start your implementation here!
- [Help center](https://help.batch.com/en/): answers to most questions you may have during the integration
- [API reference](https://doc.batch.com/ios-api-reference/index.html): this documents each of the classes and methods in the Batch iOS SDK

You may also find this guide useful to review after integration to make sure you're ready to go live: [How can I test the integration on iOS?](https://help.batch.com/en/articles/2669866-how-can-i-test-the-integration-on-ios)

# Releases
We support Cocoapods, Carthage and SPM. You can also [integrate the Batch iOS SDK manually](https://doc.batch.com/ios/advanced/general#manual-framework-integration). 
 
# Building

Build instructions are detailed in [BUILDING.md](BUILDING.md).

# Contributing
Please refer to our [contributing guidelines](CONTRIBUTING.md).
